VERSION 5.00
Begin VB.UserControl BarGauge 
   AutoRedraw      =   -1  'True
   ClientHeight    =   345
   ClientLeft      =   0
   ClientTop       =   0
   ClientWidth     =   1755
   ForeColor       =   &H00FFFFFF&
   ScaleHeight     =   345
   ScaleWidth      =   1755
   ToolboxBitmap   =   "BarGauge.ctx":0000
End
Attribute VB_Name = "BarGauge"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Option Explicit

' Default property values
Private Const m_def_Minimum = 0
Private Const m_def_Maximum = 100
Private Const m_def_Value = 40

' Property variables.
Private m_Minimum As Single
Private m_Maximum As Single
Private m_Value As Single

' Event declarations.
Event ValueScroll()
Event ValueChanged()

Private m_Dragging As Boolean
' Display the current value.
Private Sub DisplayValue()
Dim X As Single

    ' Erase any previous line.
    Cls

    ' Draw the new line.
    On Error Resume Next
    X = ScaleWidth * (m_Value - m_Minimum) / (m_Maximum - m_Minimum)
    Line (X, 0)-Step(0, ScaleHeight)
End Sub

Private Sub UserControl_Initialize()
    DrawBackground
End Sub

' Start dragging.
Private Sub UserControl_MouseDown(Button As Integer, Shift As Integer, X As Single, Y As Single)
    m_Dragging = True

    ' Calculate and display the new value.
    m_Value = m_Minimum + (m_Maximum - m_Minimum) * X / ScaleWidth
    DisplayValue
    RaiseEvent ValueScroll
End Sub
Public Property Get Minimum() As Single
    Minimum = m_Minimum
End Property

Public Property Let Minimum(ByVal New_Minimum As Single)
    m_Minimum = New_Minimum
    PropertyChanged "Minimum"
End Property

Public Property Get Maximum() As Single
    Maximum = m_Maximum
End Property

Public Property Let Maximum(ByVal New_Maximum As Single)
    m_Maximum = New_Maximum
    PropertyChanged "Maximum"
End Property

Public Property Get Value() As Single
    Value = m_Value
End Property

Public Property Let Value(ByVal New_Value As Single)
    m_Value = New_Value
    PropertyChanged "Value"

    ' Display the new value.
    DisplayValue
End Property
Private Sub UserControl_InitProperties()
    m_Minimum = m_def_Minimum
    m_Maximum = m_def_Maximum
    m_Value = m_def_Value
End Sub

' Continue dragging.
Private Sub UserControl_MouseMove(Button As Integer, Shift As Integer, X As Single, Y As Single)
    If Not m_Dragging Then Exit Sub

    ' Calculate and display the new value.
    If X < 0 Then X = 0
    If X > ScaleWidth Then X = ScaleWidth
    m_Value = m_Minimum + (m_Maximum - m_Minimum) * X / ScaleWidth
    DisplayValue
    RaiseEvent ValueScroll
End Sub

' Finish the drag.
Private Sub UserControl_MouseUp(Button As Integer, Shift As Integer, X As Single, Y As Single)
    If Not m_Dragging Then Exit Sub
    m_Dragging = False

    RaiseEvent ValueChanged
End Sub


Private Sub UserControl_ReadProperties(PropBag As PropertyBag)
    m_Minimum = PropBag.ReadProperty("Minimum", m_def_Minimum)
    m_Maximum = PropBag.ReadProperty("Maximum", m_def_Maximum)
    m_Value = PropBag.ReadProperty("Value", m_def_Value)
    UserControl.ForeColor = PropBag.ReadProperty("ForeColor", &HFFFFFF)

    DisplayValue
End Sub

' Draw a background.
Private Sub DrawBackground()
Dim i As Integer
Dim clr As Integer
Dim dclr As Single
Dim hgt As Single

    ' Give the slider an interesting background.
    UserControl.ScaleMode = vbPixels
    dclr = 256 / UserControl.ScaleWidth
    hgt = UserControl.ScaleHeight
    For i = 0 To UserControl.ScaleWidth
        clr = i * dclr
        UserControl.Line (i, 0)-(i, hgt), RGB(0, 0, clr)
    Next i

    ' Make the image permanent.
    UserControl.Picture = UserControl.Image

    ' Prepare.
    UserControl.DrawWidth = 2
End Sub

Private Sub UserControl_Resize()
    DrawBackground
    DisplayValue
End Sub

Private Sub UserControl_WriteProperties(PropBag As PropertyBag)
    PropBag.WriteProperty "Minimum", m_Minimum, m_def_Minimum
    PropBag.WriteProperty "Maximum", m_Maximum, m_def_Maximum
    PropBag.WriteProperty "Value", m_Value, m_def_Value
    PropBag.WriteProperty "ForeColor", UserControl.ForeColor, &HFFFFFF
End Sub

Public Property Get ForeColor() As OLE_COLOR
Attribute ForeColor.VB_Description = "Returns/sets the foreground color used to display text and graphics in an object."
    ForeColor = UserControl.ForeColor
End Property

Public Property Let ForeColor(ByVal New_ForeColor As OLE_COLOR)
    UserControl.ForeColor() = New_ForeColor
    PropertyChanged "ForeColor"

    DisplayValue
End Property

